@@ -5,7 +5,7 @@
 var operator_position = {
   sanity: [
     'var res = a + b - c / d * e % f;',
-    'var res = g & h | i ^ j;',
+    'var res = g & h | i ^ j |> console.log;',
     'var res = (k && l || m) ? n : o;',
     'var res = p >> q << r >>> s;',
     'var res = t === u !== v != w == x >= y <= z > aa < ab;',
@@ -19,7 +19,8 @@ var operator_position = {
     'f;',
     '   var res = g & h',
     '| i ^',
-    'j;',
+    'j',
+    '|> console.log;',
     'var res = (k &&',
     'l',
     '|| m) ?',
